/** \file
 * Copyright (c) 1999 Carlo Wood.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef INDENT_COMMENTS_H
#define INDENT_COMMENTS_H

#include "sys.h" /* for RCSTAG_H */

RCSTAG_H (comments, "$Id$");

#include <indent.h> /* For BOOLEAN */

extern void print_comment(
    int     * paren_targ,
    BOOLEAN * pbreak_line);

#endif /* INDENT_COMMENTS_H */
